searchData={"items":[{"type":"module","title":"Membrane.Smelter","doc":"Membrane SDK for [Smelter](https://github.com/software-mansion/smelter).","ref":"Membrane.Smelter.html"},{"type":"module","title":"Input streams - Membrane.Smelter","doc":"Each input pad has a format `Pad.ref(:video_input, input_id)` or `Pad.ref(:audio_input, input_id)`,\nwhere `input_id` is a string. `input_id` needs to be unique for all input pads, in particular\nyou can't have audio and video input pads with the same id.\n\nSee `Membrane.Smelter.Lifecycle` for input stream lifecycle notifications.","ref":"Membrane.Smelter.html#module-input-streams"},{"type":"module","title":"Output streams - Membrane.Smelter","doc":"Each output pad has a format `Pad.ref(:video_output, output_id)` or `Pad.ref(:audio_output, output_id)`,\nwhere `output_id` is a string. `output_id` needs to be unique for all output pads, in particular\nyou can't have audio and video output pads with the same id.\n\nAfter registering and linking an output stream Smelter will notify the parent with\n[`output_registered/0`](`t:Membrane.Smelter.Lifecycle.output_registered/0`).","ref":"Membrane.Smelter.html#module-output-streams"},{"type":"module","title":"Composition specification - `video` - Membrane.Smelter","doc":"To specify what Smelter should render you can:\n- Define `initial` option when connecting `:video_output` pad.\n- Send [`Request.UpdateVideoOutput`](`Membrane.Smelter.Request.UpdateVideoOutput`)\nnotification to update a scene on an already connected pad.\n\nFor example, code snippet bellow will update content of a stream from `Pad.ref(:video_output, \"output_0\")`\nto include streams from `Pad.ref(:video_input, \"input_0\")` and `Pad.ref(:video_input, \"input_1\")`\nside by side using [`Tiles`](https://smelter.dev/http-api/components/tiles) component.\n\n```\nscene_update_request =  %Request.UpdateVideoOutput{\n  output_id: \"output_0\"\n  root: %{\n    type: :tiles,\n    children: [\n      { type: \"input_stream\", input_id: \"input_0\" },\n      { type: \"input_stream\", input_id: \"input_1\" }\n    ]\n  }\n}\n\n{[notify_child: {:smelter, scene_update_request}]}\n```\n\n`:root` option specifies root component of a scene that will be rendered on the output stream.\nConcept of a component is explained [here](https://smelter.dev/http-api/overview#components). For\nactual component definitions see Smelter documentation e.g.\n[`View`](https://smelter.dev/http-api/components/view),\n[`Tiles`](https://smelter.dev/http-api/components/tiles), ...","ref":"Membrane.Smelter.html#module-composition-specification-video"},{"type":"module","title":"Composition specification - `audio` - Membrane.Smelter","doc":"- Define `initial` option when connecting `:audio_output` pad.\n- Send [`Request.UpdateAudioOutput`](`Membrane.Smelter.Request.UpdateAudioOutput`)\nnotification to audio composition on an already connected pad.\n\nFor example, code snippet bellow will update content of a stream from `Pad.ref(:video_output, \"output_0\")`\nto include streams from `Pad.ref(:video_input, \"input_0\")` and `Pad.ref(:video_input, \"input_1\")`\nmixed together, where `\"input_0\"` is mixed at half volume.\n\n```\naudio_update_request =  %Request.UpdateAudioOutput{\n  output_id: \"output_0\"\n  inputs: [\n    { input_id: \"input_0\", volume: 0.5 },\n    { input_id: \"input_1\" }\n  ]\n}\n\n{[notify_child: {:smelter, audio_update_request}]}\n```","ref":"Membrane.Smelter.html#module-composition-specification-audio"},{"type":"module","title":"Notifications - Membrane.Smelter","doc":"Smelter bin can send following notifications to the parent process.\n- [`Lifecycle.notification/0`](`t:Membrane.Smelter.Lifecycle.notification/0`) -\nNotification about lifecycle of input/output streams.\n- [`Request.result/0`](`t:Membrane.Smelter.Request.result/0`) - Result of a\n`Membrane.Smelter.Request` sent from the parent process.","ref":"Membrane.Smelter.html#module-notifications"},{"type":"module","title":"Smelter documentation - Membrane.Smelter","doc":"This documentation covers mostly Elixr/Membrane specific API. For platform/language independent topics\nthat are not covered here check [Smelter documentation](https://smelter.dev/http-api/overview).","ref":"Membrane.Smelter.html#module-smelter-documentation"},{"type":"module","title":"Bin options - Membrane.Smelter","doc":"Passed via struct `t:Membrane.Smelter.t/0`\n\n- `framerate`  \n\n  ```\n  Membrane.RawVideo.framerate()\n  ```\n  \n  ***Required***  \n  Framerate of Smelter outputs.\n\n\n- `output_sample_rate`  \n\n  ```\n  output_sample_rate()\n  ```\n  \n  Default value: `48000`  \n  Sample rate of audio on Smelter outputs.\n\n\n\n- `api_port`  \n\n  ```\n  :inet.port_number() | port_range()\n  ```\n  \n  Default value: `8081`  \n  Port number or port range where Smelter will be hosted.\n\n\n\n- `stream_fallback_timeout`  \n\n  ```\n  Membrane.Time.t()\n  ```\n  \n  Default value: `500000000`  \n  Timeout that defines when Smelter should switch to fallback on\n  the input stream that stopped sending frames.\n\n\n\n- `composing_strategy`  \n\n  ```\n  :real_time_auto_init | :real_time | :offline_processing\n  ```\n  \n  Default value: `:real_time_auto_init`  \n  Specifies Smelter mode for composing frames:\n  - `:real_time` - Frames are produced at a rate dictated by real time clock. The parent\n  process has to send `:start_composing` message to start.\n  - `:real_time_auto_init` - The same as `:real_time`, but the pipeline starts\n  automatically and sending `:start_composing` message is not necessary.\n  - `:offline_processing`\n    - Output streams will be produced faster than in real time if input streams are\n    ready.\n    - Never drop output frames, even if the encoder or rendering process is not able to\n    process data in real time.\n  \n      When using this option, make sure to register the output stream before starting;\n      otherwise, Smelter will run in a busy loop processing data far into the future.\n\n\n\n- `server_setup`  \n\n  ```\n  :already_started\n  | {:already_started, :inet.ip_address() | String.t() | atom()}\n  | :start_locally\n  | {:start_locally, path :: String.t()}\n  ```\n  \n  Default value: `:start_locally`  \n  Defines how Smelter bin should start-up a its server.\n  \n  Available options:\n  - `:start_locally` - Smelter server is automatically started.\n  - `{:start_locally, path}` - Smelter server is automatically started, but different binary\n  is used to spawn the process.\n  - `:already_started` - Smelter bin assumes, that the server is already started\n  and is available on a localhost on a specified port. When this option is selected, the\n  `api_port` option need to specify an exact port number (not a range).\n  - `{:already_started, ip_or_hostname}` - Smelter bin assumes, that the server is already\n  started and is available on a specified IP or name on a specified port. When this option is\n  selected, the `api_port` option need to specify an exact port number (not a range). If\n  `ip_or_hostname` is a string or an atom, it will be resolved to `:inet.ip_address()` using\n  `:inet.gethostbyname/1`.\n\n\n\n- `init_requests`  \n\n  ```\n  list(Request.t())\n  ```\n  \n  Default value: `[]`  \n  Requests that will be sent on startup to Smelter server. It's main use case is to\n  register renderers that will be needed in the scene from the very beginning.\n  \n  Example:\n  ```\n  [%Request.RegisterShader{\n    shader_id: \"example_shader_1\",\n    source: \" \"\n  }]\n  ```","ref":"Membrane.Smelter.html#module-bin-options"},{"type":"module","title":"Pads - Membrane.Smelter","doc":"### `:audio_input`\n\nAccepted formats:\n```\n%Opus{self_delimiting?: false}\n```\n```\n%RemoteStream{type: :packetized, content_format: Opus}\n```\n```\n%RemoteStream{type: :packetized, content_format: nil}\n```\n\nDirection: | `:input`\nAvailability: | `:on_request`\nPad options:\n\n- `required`  \n\n  ```\n  boolean()\n  ```\n  \n  Default value: `false`  \n  If stream is marked required Smelter will delay processing new frames until\n  frames are available. In particular, if there is at least one required input stream and the\n  encoder is not able to produce frames on time, the output stream will also be delayed. This\n  delay will happen regardless of whether required input stream was on time or not.\n\n\n- `offset`  \n\n  ```\n  Membrane.Time.t() | nil\n  ```\n  \n  Default value: `nil`  \n  An optional offset used for stream synchronization. This value represents how PTS values of the\n  stream are shifted relative to the start request. If not defined streams are synchronized\n  based on the delivery times of initial frames.\n\n\n\n- `port`  \n\n  ```\n  :inet.port_number() | port_range()\n  ```\n  \n  Default value: `{10000, 60000}`  \n  Port number or port range.\n  \n  Internally Smelter server communicates with this pipeline locally over RTP.\n  This value defines which TCP ports will be used.\n\n\n\n\n### `:video_input`\n\nAccepted formats:\n```\n%Membrane.H264{alignment: :nalu, stream_structure: :annexb}\n```\n\nDirection: | `:input`\nAvailability: | `:on_request`\nPad options:\n\n- `required`  \n\n  ```\n  boolean()\n  ```\n  \n  Default value: `false`  \n  If stream is marked required Smelter will delay processing new frames until\n  frames are available. In particular, if there is at least one required input stream and the\n  encoder is not able to produce frames on time, the output stream will also be delayed. This\n  delay will happen regardless of whether required input stream was on time or not.\n\n\n- `offset`  \n\n  ```\n  Membrane.Time.t() | nil\n  ```\n  \n  Default value: `nil`  \n  An optional offset used for stream synchronization. This value represents how PTS values of the\n  stream are shifted relative to the start request. If not defined streams are synchronized\n  based on the delivery times of initial frames.\n\n\n\n- `port`  \n\n  ```\n  :inet.port_number() | port_range()\n  ```\n  \n  Default value: `{10000, 60000}`  \n  Port number or port range.\n  \n  Internally Smelter server communicates with this pipeline locally over RTP.\n  This value defines which TCP ports will be used.\n\n\n\n\n\n### `:audio_output`\n\nAccepted formats:\n```\n%RemoteStream{type: :packetized, content_format: Opus}\n```\n\nDirection: | `:output`\nAvailability: | `:on_request`\nPad options:\n\n- `port`  \n\n  ```\n  :inet.port_number() | port_range()\n  ```\n  \n  Default value: `{10000, 60000}`  \n  Port number or port range.\n  \n  Internally Smelter server communicates with this pipeline locally over RTP.\n  This value defines which TCP ports will be used.\n\n\n- `encoder`  \n\n  ```\n  Encoder.Opus.t()\n  ```\n  \n  ***Required***  \n  \n\n\n\n- `send_eos_when`  \n\n  ```\n  send_eos_condition()\n  ```\n  \n  Default value: `nil`  \n  Condition for automatically finishing output stream in response to end of input streams.\n  \n  - `{:any_of, input_ids}` - End the output stream if any of the inputs from the list finished\n  or if they don't exist.\n  - `{:all_of, input_ids}` - End the output stream if all of the inputs from the list finished\n  or if they don't exist.\n  - `:any_input` - End the output stream when any input stream finishes.\n  - `:all_inputs` - End the output stream when all of the input streams have finished. This\n  also includes a case where no inputs are were ever connected.\n\n\n\n- `initial`  \n\n  ```\n  any()\n  ```\n  \n  ***Required***  \n  Initial audio mixer configuration that will be produced on this output.\n  \n  Example:\n  ```\n  %{\n    inputs: [\n      %{ input_id: \"input_0\" },\n      %{ input_id: \"input_0\", volume: 0.5 }\n    ]\n  }\n  ```\n  \n  To change the scene after the registration you can send `%Request.UpdateAudioOutput{}`\n  notification.\n\n\n\n\n\n### `:video_output`\n\nAccepted formats:\n```\n%Membrane.H264{alignment: :nalu, stream_structure: :annexb}\n```\n\nDirection: | `:output`\nAvailability: | `:on_request`\nPad options:\n\n- `port`  \n\n  ```\n  :inet.port_number() | port_range()\n  ```\n  \n  Default value: `{10000, 60000}`  \n  Port number or port range.\n  \n  Internally Smelter server communicates with this pipeline locally over RTP.\n  This value defines which TCP ports will be used.\n\n\n- `width`  \n\n  ```\n  non_neg_integer()\n  ```\n  \n  ***Required***  \n  \n\n\n\n- `height`  \n\n  ```\n  non_neg_integer()\n  ```\n  \n  ***Required***  \n  \n\n\n\n- `encoder`  \n\n  ```\n  Encoder.FFmpegH264.t()\n  ```\n  \n  ***Required***  \n  \n\n\n\n- `send_eos_when`  \n\n  ```\n  send_eos_condition()\n  ```\n  \n  Default value: `nil`  \n  Condition for automatically finishing output stream in response to end of input streams.\n  \n  - `{:any_of, input_ids}` - End the output stream if any of the inputs from the list finished\n  or if they don't exist.\n  - `{:all_of, input_ids}` - End the output stream if all of the inputs from the list finished\n  or if they don't exist.\n  - `:any_input` - End the output stream when any input stream finishes.\n  - `:all_inputs` - End the output stream when all of the input streams have finished. This\n  also includes a case where no inputs are were ever connected.\n\n\n\n- `initial`  \n\n  ```\n  any()\n  ```\n  \n  ***Required***  \n  Initial scene that will be rendered on this output.\n  \n  Example:\n  ```\n  %{\n    root: %{\n      type: :view,\n      children: [\n        %{ type: :input_stream, input_id: \"input_0\" }\n      ]\n    }\n  }\n  ```\n  \n  To change the scene after the registration you can send `%Request.UpdateVideoOutput{}`\n  notification.\n  \n  Format of the `:root` field is documented [here](https://smelter.dev/http-api/overview#components).\n  For specific options see documentation pages for each component e.g.\n  [`View`](https://smelter.dev/http-api/components/view),\n  [`Tiles`](https://smelter.dev/http-api/components/tiles), ...","ref":"Membrane.Smelter.html#module-pads"},{"type":"type","title":"Membrane.Smelter.audio_input_pad_opts/0","doc":"Options for pad `:audio_input`","ref":"Membrane.Smelter.html#t:audio_input_pad_opts/0"},{"type":"type","title":"Membrane.Smelter.audio_output_pad_opts/0","doc":"Options for pad `:audio_output`","ref":"Membrane.Smelter.html#t:audio_output_pad_opts/0"},{"type":"type","title":"Membrane.Smelter.input_id/0","doc":"Input stream id, uniquely identifies an input pad.","ref":"Membrane.Smelter.html#t:input_id/0"},{"type":"function","title":"Membrane.Smelter.options/0","doc":"Returns description of options available for this module","ref":"Membrane.Smelter.html#options/0"},{"type":"type","title":"Membrane.Smelter.output_id/0","doc":"Output stream id, uniquely identifies an output pad.","ref":"Membrane.Smelter.html#t:output_id/0"},{"type":"type","title":"Membrane.Smelter.output_sample_rate/0","doc":"Supported output sample rates.","ref":"Membrane.Smelter.html#t:output_sample_rate/0"},{"type":"type","title":"Membrane.Smelter.port_range/0","doc":"Range of ports.","ref":"Membrane.Smelter.html#t:port_range/0"},{"type":"type","title":"Membrane.Smelter.send_eos_condition/0","doc":"Condition that defines when output stream should end depending on the\nEOS received on inputs.","ref":"Membrane.Smelter.html#t:send_eos_condition/0"},{"type":"type","title":"Membrane.Smelter.t/0","doc":"Struct containing options for `Membrane.Smelter`","ref":"Membrane.Smelter.html#t:t/0"},{"type":"type","title":"Membrane.Smelter.video_input_pad_opts/0","doc":"Options for pad `:video_input`","ref":"Membrane.Smelter.html#t:video_input_pad_opts/0"},{"type":"type","title":"Membrane.Smelter.video_output_pad_opts/0","doc":"Options for pad `:video_output`","ref":"Membrane.Smelter.html#t:video_output_pad_opts/0"},{"type":"module","title":"Membrane.Smelter.Context","doc":"Context of Smelter. Specifies Smelter inputs and outputs.","ref":"Membrane.Smelter.Context.html"},{"type":"type","title":"Membrane.Smelter.Context.t/0","doc":"Context of Smelter. Specifies Smelter inputs and outputs.","ref":"Membrane.Smelter.Context.html#t:t/0"},{"type":"module","title":"Membrane.Smelter.Lifecycle","doc":"Lifecycle of the input and output streams.","ref":"Membrane.Smelter.Lifecycle.html"},{"type":"module","title":"Input pad - Membrane.Smelter.Lifecycle","doc":"- `t:input_registered/0`\n- `t:input_delivered/0`\n- `t:input_playing/0`\n- `t:input_eos/0`","ref":"Membrane.Smelter.Lifecycle.html#module-input-pad"},{"type":"module","title":"Output pad - Membrane.Smelter.Lifecycle","doc":"- `t:output_registered/0`","ref":"Membrane.Smelter.Lifecycle.html#module-output-pad"},{"type":"module","title":"Notifications - Membrane.Smelter.Lifecycle","doc":"`t:notification/0` defines notifications that will be sent to the parent process at the specific\nmoments of the stream lifecycle.","ref":"Membrane.Smelter.Lifecycle.html#module-notifications"},{"type":"type","title":"Membrane.Smelter.Lifecycle.input_delivered/0","doc":"The smelter instance received the input. The first frames/samples of that input are\nready to be used.\n\nFor example, if you want to ensure that some inputs are ready before you send the\n`:start_composing` notification, you can wait for `t:input_delivered/0` for specific inputs.\nNote that you need to set `composing_strategy:` to something other than `:real_time_auto_init`\nif you want to send `:start_composing` message yourself.","ref":"Membrane.Smelter.Lifecycle.html#t:input_delivered/0"},{"type":"type","title":"Membrane.Smelter.Lifecycle.input_eos/0","doc":"Input finished processing. After this notification you can unregister without drooping any\nframes/samples","ref":"Membrane.Smelter.Lifecycle.html#t:input_eos/0"},{"type":"type","title":"Membrane.Smelter.Lifecycle.input_playing/0","doc":"The smelter instance received the input, and the first frames/samples of that input are used\nfor rendering. This notification can only be sent if Smelter was already started either via\n`composing_strategy: :real_time_auto_init` or with `:start_composing` message.\n\nThis notification is usually sent at the same time as `t:input_delivered/0` except for 2 cases:\n- First frames/samples of the input were delivered before composing was started.\n- If input has the `offset` field defined.","ref":"Membrane.Smelter.Lifecycle.html#t:input_playing/0"},{"type":"type","title":"Membrane.Smelter.Lifecycle.input_registered/0","doc":"The input pad was linked and the TCP connection was established between pipeline and\nthe smelter instance.","ref":"Membrane.Smelter.Lifecycle.html#t:input_registered/0"},{"type":"type","title":"Membrane.Smelter.Lifecycle.notification/0","doc":"","ref":"Membrane.Smelter.Lifecycle.html#t:notification/0"},{"type":"type","title":"Membrane.Smelter.Lifecycle.output_registered/0","doc":"The output pad was linked and the TCP connection was established between pipeline and\nthe smelter instance.","ref":"Membrane.Smelter.Lifecycle.html#t:output_registered/0"},{"type":"module","title":"Membrane.Smelter.Encoder.FFmpegH264","doc":"Options for H264 encoder from FFmpeg.","ref":"Membrane.Smelter.Encoder.FFmpegH264.html"},{"type":"type","title":"Membrane.Smelter.Encoder.FFmpegH264.encoder_preset/0","doc":"Encoder preset. See [FFmpeg docs](https://trac.ffmpeg.org/wiki/Encode/H.264#Preset)\nto learn more.","ref":"Membrane.Smelter.Encoder.FFmpegH264.html#t:encoder_preset/0"},{"type":"type","title":"Membrane.Smelter.Encoder.FFmpegH264.ffmpeg_options/0","doc":"Raw FFmpeg encoder options. See [docs](https://ffmpeg.org/ffmpeg-codecs.html) for more.","ref":"Membrane.Smelter.Encoder.FFmpegH264.html#t:ffmpeg_options/0"},{"type":"type","title":"Membrane.Smelter.Encoder.FFmpegH264.t/0","doc":"","ref":"Membrane.Smelter.Encoder.FFmpegH264.html#t:t/0"},{"type":"module","title":"Membrane.Smelter.Encoder.Opus","doc":"Options for OPUS encoder.","ref":"Membrane.Smelter.Encoder.Opus.html"},{"type":"type","title":"Membrane.Smelter.Encoder.Opus.channels/0","doc":"","ref":"Membrane.Smelter.Encoder.Opus.html#t:channels/0"},{"type":"type","title":"Membrane.Smelter.Encoder.Opus.encoder_preset/0","doc":"Encoder preset.","ref":"Membrane.Smelter.Encoder.Opus.html#t:encoder_preset/0"},{"type":"type","title":"Membrane.Smelter.Encoder.Opus.t/0","doc":"","ref":"Membrane.Smelter.Encoder.Opus.html#t:t/0"},{"type":"module","title":"Membrane.Smelter.Request","doc":"Notifications that can be sent to Smelter to trigger certain actions.\n\nAfter request is handled (but not necessarily completed e.g. if you schedule some action) the bin will\nrespond with `t:result/0`.","ref":"Membrane.Smelter.Request.html"},{"type":"type","title":"Membrane.Smelter.Request.result/0","doc":"","ref":"Membrane.Smelter.Request.html#t:result/0"},{"type":"type","title":"Membrane.Smelter.Request.t/0","doc":"","ref":"Membrane.Smelter.Request.html#t:t/0"},{"type":"module","title":"Membrane.Smelter.Request.KeyframeRequest","doc":"Request to trigger additional keyframe generation for a specified output.","ref":"Membrane.Smelter.Request.KeyframeRequest.html"},{"type":"type","title":"Membrane.Smelter.Request.KeyframeRequest.t/0","doc":"- `:output_id` - Id of the output for which additional keyframe should be generated.","ref":"Membrane.Smelter.Request.KeyframeRequest.html#t:t/0"},{"type":"module","title":"Membrane.Smelter.Request.RegisterImage","doc":"Request to register an image.","ref":"Membrane.Smelter.Request.RegisterImage.html"},{"type":"type","title":"Membrane.Smelter.Request.RegisterImage.image_type/0","doc":"Image type","ref":"Membrane.Smelter.Request.RegisterImage.html#t:image_type/0"},{"type":"type","title":"Membrane.Smelter.Request.RegisterImage.t/0","doc":"- Fields `url` and `path` are mutually exclusive. Exactly one of them should be set at the time.\n- Field `resolution` is only supported when `:asset_type` is set to `:svg`.","ref":"Membrane.Smelter.Request.RegisterImage.html#t:t/0"},{"type":"module","title":"Membrane.Smelter.Request.RegisterShader","doc":"Request to register a shader instance.","ref":"Membrane.Smelter.Request.RegisterShader.html"},{"type":"type","title":"Membrane.Smelter.Request.RegisterShader.shader_source/0","doc":"WGSL shader source code. [Learn more](https://smelter.dev/fundamentals/concepts/shaders).","ref":"Membrane.Smelter.Request.RegisterShader.html#t:shader_source/0"},{"type":"type","title":"Membrane.Smelter.Request.RegisterShader.t/0","doc":"","ref":"Membrane.Smelter.Request.RegisterShader.html#t:t/0"},{"type":"module","title":"Membrane.Smelter.Request.UnregisterImage","doc":"Request to unregister an image.","ref":"Membrane.Smelter.Request.UnregisterImage.html"},{"type":"type","title":"Membrane.Smelter.Request.UnregisterImage.t/0","doc":"","ref":"Membrane.Smelter.Request.UnregisterImage.html#t:t/0"},{"type":"module","title":"Membrane.Smelter.Request.UnregisterInput","doc":"Request to unregister an input stream. Unregister will happen automatically when you unlink the\npads.","ref":"Membrane.Smelter.Request.UnregisterInput.html"},{"type":"type","title":"Membrane.Smelter.Request.UnregisterInput.t/0","doc":"","ref":"Membrane.Smelter.Request.UnregisterInput.html#t:t/0"},{"type":"module","title":"Membrane.Smelter.Request.UnregisterOutput","doc":"Request to unregister an output stream. Unregister will happen automatically when you unlink the\npads.","ref":"Membrane.Smelter.Request.UnregisterOutput.html"},{"type":"type","title":"Membrane.Smelter.Request.UnregisterOutput.t/0","doc":"","ref":"Membrane.Smelter.Request.UnregisterOutput.html#t:t/0"},{"type":"module","title":"Membrane.Smelter.Request.UnregisterShader","doc":"Request to unregister a shader instance.","ref":"Membrane.Smelter.Request.UnregisterShader.html"},{"type":"type","title":"Membrane.Smelter.Request.UnregisterShader.t/0","doc":"","ref":"Membrane.Smelter.Request.UnregisterShader.html#t:t/0"},{"type":"module","title":"Membrane.Smelter.Request.UpdateAudioOutput","doc":"Request to update configuration of an audio output. You can define what inputs and volume should\nbe used to produce the output.","ref":"Membrane.Smelter.Request.UpdateAudioOutput.html"},{"type":"type","title":"Membrane.Smelter.Request.UpdateAudioOutput.input/0","doc":"- `input_id` - ID of an input that will be used to produce output.\n- `volume` - Number between 0 and 1 that represent volume of the input.","ref":"Membrane.Smelter.Request.UpdateAudioOutput.html#t:input/0"},{"type":"type","title":"Membrane.Smelter.Request.UpdateAudioOutput.t/0","doc":"- `:output_id` - Id of the output that should be updated.\n- `:inputs` - Inputs and their configuration that should be mixed to produce the output audio.\n- `:schedule_time` - Schedule this update at a specific time. Time is measured from Smelter\nstart. If not defined, update will be applied immediately.","ref":"Membrane.Smelter.Request.UpdateAudioOutput.html#t:t/0"},{"type":"module","title":"Membrane.Smelter.Request.UpdateVideoOutput","doc":"Request to update the scene definition that describes what should be rendered on a specified output.","ref":"Membrane.Smelter.Request.UpdateVideoOutput.html"},{"type":"type","title":"Membrane.Smelter.Request.UpdateVideoOutput.t/0","doc":"- `:output_id` - Id of the output that should be updated.\n- `:root` - Root of a component tree/scene that should be rendered for the output. [Learn more](https://smelter.dev/http-api/overview#components)\n- `:schedule_time` - Schedule this update at a specific time. Time is measured from Smelter\nstart. If not defined, update will be applied immediately.","ref":"Membrane.Smelter.Request.UpdateVideoOutput.html#t:t/0"},{"type":"extras","title":"Membrane Smelter Plugin","doc":"# Membrane Smelter Plugin\n\n[![Hex.pm](https://img.shields.io/hexpm/v/membrane_smelter_plugin.svg)](https://hex.pm/packages/membrane_smelter_plugin)\n[![API Docs](https://img.shields.io/badge/api-docs-yellow.svg?style=flat)](https://hexdocs.pm/membrane_smelter_plugin)\n[![CircleCI](https://dl.circleci.com/status-badge/img/gh/membraneframework/membrane_smelter_plugin/tree/master.svg?style=svg)](https://dl.circleci.com/status-badge/redirect/gh/membraneframework/membrane_smelter_plugin/tree/master)\n\nMembrane SDK for [Smelter](https://smelter.dev), that takes multiple input streams, transforms them according to provided transformations and composes them into output streams / videos.\n\nIt is part of [Membrane Multimedia Framework](https://membrane.stream).","ref":"readme.html"},{"type":"extras","title":"Installation - Membrane Smelter Plugin","doc":"The package can be installed by adding `membrane_smelter_plugin` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:membrane_smelter_plugin, \"~> 0.11.1\"}\n  ]\nend\n```\n\nSmelter requires having locally installed:\n\n- [FFmpeg 6.0](https://ffmpeg.org/download.html) - for streaming inputs / outputs to Smelter\n- [wget](https://www.gnu.org/software/wget/) - for downloading Smelter binary file\n- [tar](https://www.gnu.org/software/tar/) - for decompressing Smelter binary file","ref":"readme.html#installation"},{"type":"extras","title":"Examples - Membrane Smelter Plugin","doc":"Examples can be found in `examples` directory.\n\nTo run example run:\n\n1. `cd examples`\n2. `mix deps.get`\n3. `mix run lib/[example_name].exs`","ref":"readme.html#examples"},{"type":"extras","title":"Layout with shader example - Membrane Smelter Plugin","doc":"The example presents dynamically added video arranged onto a tiled layout and \"twisted\" with the simple shader. Shaders can be used to create custom visual effects.","ref":"readme.html#layout-with-shader-example"},{"type":"extras","title":"Transition example - Membrane Smelter Plugin","doc":"The example presents dynamic transition of input videos. Transitions are used for smooth, dynamical animations.","ref":"readme.html#transition-example"},{"type":"extras","title":"Dynamic outputs example - Membrane Smelter Plugin","doc":"The example presents dynamic outputs linking.\nMultiple outputs are useful for live-streaming for multiple platforms (e.g. different layout for mobile devices), target resolutions\nor any other case, when user want to process input videos differently.","ref":"readme.html#dynamic-outputs-example"},{"type":"extras","title":"Offline processing example - Membrane Smelter Plugin","doc":"Example of processing that does not need to be real time. Multiple offline sources (mp4 files) are composed together and\nproduce output mp4 file. To simplify the example the same input file is read multiple times as a separate inputs. Depending\non hardware capabilities this example can run faster or slower than real time.","ref":"readme.html#offline-processing-example"},{"type":"extras","title":"LICENSE","doc":"Membrane Smelter plugin is using Smelter that is licensed\nunder custom license.\n\nSee https://github.com/software-mansion/smelter/blob/master/LICENSE\nto learn more.\n\n-----------------------------------------------------------------------------\n\nMembrane Smelter plugin on its own is licensed under Apache-2.0 license\nincluded below.\n\n                                 Apache License\n                           Version 2.0, January 2004\n                        http://www.apache.org/licenses/\n\n   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION\n\n   1. Definitions.\n\n      \"License\" shall mean the terms and conditions for use, reproduction,\n      and distribution as defined by Sections 1 through 9 of this document.\n\n      \"Licensor\" shall mean the copyright owner or entity authorized by\n      the copyright owner that is granting the License.\n\n      \"Legal Entity\" shall mean the union of the acting entity and all\n      other entities that control, are controlled by, or are under common\n      control with that entity. For the purposes of this definition,\n      \"control\" means (i) the power, direct or indirect, to cause the\n      direction or management of such entity, whether by contract or\n      otherwise, or (ii) ownership of fifty percent (50%) or more of the\n      outstanding shares, or (iii) beneficial ownership of such entity.\n\n      \"You\" (or \"Your\") shall mean an individual or Legal Entity\n      exercising permissions granted by this License.\n\n      \"Source\" form shall mean the preferred form for making modifications,\n      including but not limited to software source code, documentation\n      source, and configuration files.\n\n      \"Object\" form shall mean any form resulting from mechanical\n      transformation or translation of a Source form, including but\n      not limited to compiled object code, generated documentation,\n      and conversions to other media types.\n\n      \"Work\" shall mean the work of authorship, whether in Source or\n      Object form, made available under the License, as indicated by a\n      copyright notice that is included in or attached to the work\n      (an example is provided in the Appendix below).\n\n      \"Derivative Works\" shall mean any work, whether in Source or Object\n      form, that is based on (or derived from) the Work and for which the\n      editorial revisions, annotations, elaborations, or other modifications\n      represent, as a whole, an original work of authorship. For the purposes\n      of this License, Derivative Works shall not include works that remain\n      separable from, or merely link (or bind by name) to the interfaces of,\n      the Work and Derivative Works thereof.\n\n      \"Contribution\" shall mean any work of authorship, including\n      the original version of the Work and any modifications or additions\n      to that Work or Derivative Works thereof, that is intentionally\n      submitted to Licensor for inclusion in the Work by the copyright owner\n      or by an individual or Legal Entity authorized to submit on behalf of\n      the copyright owner. For the purposes of this definition, \"submitted\"\n      means any form of electronic, verbal, or written communication sent\n      to the Licensor or its representatives, including but not limited to\n      communication on electronic mailing lists, source code control systems,\n      and issue tracking systems that are managed by, or on behalf of, the\n      Licensor for the purpose of discussing and improving the Work, but\n      excluding communication that is conspicuously marked or otherwise\n      designated in writing by the copyright owner as \"Not a Contribution.\"\n\n      \"Contributor\" shall mean Licensor and any individual or Legal Entity\n      on behalf of whom a Contribution has been received by Licensor and\n      subsequently incorporated within the Work.\n\n   2. Grant of Copyright License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      copyright license to reproduce, prepare Derivative Works of,\n      publicly display, publicly perform, sublicense, and distribute the\n      Work and such Derivative Works in Source or Object form.\n\n   3. Grant of Patent License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      (except as stated in this section) patent license to make, have made,\n      use, offer to sell, sell, import, and otherwise transfer the Work,\n      where such license applies only to those patent claims licensable\n      by such Contributor that are necessarily infringed by their\n      Contribution(s) alone or by combination of their Contribution(s)\n      with the Work to which such Contribution(s) was submitted. If You\n      institute patent litigation against any entity (including a\n      cross-claim or counterclaim in a lawsuit) alleging that the Work\n      or a Contribution incorporated within the Work constitutes direct\n      or contributory patent infringement, then any patent licenses\n      granted to You under this License for that Work shall terminate\n      as of the date such litigation is filed.\n\n   4. Redistribution. You may reproduce and distribute copies of the\n      Work or Derivative Works thereof in any medium, with or without\n      modifications, and in Source or Object form, provided that You\n      meet the following conditions:\n\n      (a) You must give any other recipients of the Work or\n          Derivative Works a copy of this License; and\n\n      (b) You must cause any modified files to carry prominent notices\n          stating that You changed the files; and\n\n      (c) You must retain, in the Source form of any Derivative Works\n          that You distribute, all copyright, patent, trademark, and\n          attribution notices from the Source form of the Work,\n          excluding those notices that do not pertain to any part of\n          the Derivative Works; and\n\n      (d) If the Work includes a \"NOTICE\" text file as part of its\n          distribution, then any Derivative Works that You distribute must\n          include a readable copy of the attribution notices contained\n          within such NOTICE file, excluding those notices that do not\n          pertain to any part of the Derivative Works, in at least one\n          of the following places: within a NOTICE text file distributed\n          as part of the Derivative Works; within the Source form or\n          documentation, if provided along with the Derivative Works; or,\n          within a display generated by the Derivative Works, if and\n          wherever such third-party notices normally appear. The contents\n          of the NOTICE file are for informational purposes only and\n          do not modify the License. You may add Your own attribution\n          notices within Derivative Works that You distribute, alongside\n          or as an addendum to the NOTICE text from the Work, provided\n          that such additional attribution notices cannot be construed\n          as modifying the License.\n\n      You may add Your own copyright statement to Your modifications and\n      may provide additional or different license terms and conditions\n      for use, reproduction, or distribution of Your modifications, or\n      for any such Derivative Works as a whole, provided Your use,\n      reproduction, and distribution of the Work otherwise complies with\n      the conditions stated in this License.\n\n   5. Submission of Contributions. Unless You explicitly state otherwise,\n      any Contribution intentionally submitted for inclusion in the Work\n      by You to the Licensor shall be under the terms and conditions of\n      this License, without any additional terms or conditions.\n      Notwithstanding the above, nothing herein shall supersede or modify\n      the terms of any separate license agreement you may have executed\n      with Licensor regarding such Contributions.\n\n   6. Trademarks. This License does not grant permission to use the trade\n      names, trademarks, service marks, or product names of the Licensor,\n      except as required for reasonable and customary use in describing the\n      origin of the Work and reproducing the content of the NOTICE file.\n\n   7. Disclaimer of Warranty. Unless required by applicable law or\n      agreed to in writing, Licensor provides the Work (and each\n      Contributor provides its Contributions) on an \"AS IS\" BASIS,\n      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\n      implied, including, without limitation, any warranties or conditions\n      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A\n      PARTICULAR PURPOSE. You are solely responsible for determining the\n      appropriateness of using or redistributing the Work and assume any\n      risks associated with Your exercise of permissions under this License.\n\n   8. Limitation of Liability. In no event and under no legal theory,\n      whether in tort (including negligence), contract, or otherwise,\n      unless required by applicable law (such as deliberate and grossly\n      negligent acts) or agreed to in writing, shall any Contributor be\n      liable to You for damages, including any direct, indirect, special,\n      incidental, or consequential damages of any character arising as a\n      result of this License or out of the use or inability to use the\n      Work (including but not limited to damages for loss of goodwill,\n      work stoppage, computer failure or malfunction, or any and all\n      other commercial damages or losses), even if such Contributor\n      has been advised of the possibility of such damages.\n\n   9. Accepting Warranty or Additional Liability. While redistributing\n      the Work or Derivative Works thereof, You may choose to offer,\n      and charge a fee for, acceptance of support, warranty, indemnity,\n      or other liability obligations and/or rights consistent with this\n      License. However, in accepting such obligations, You may act only\n      on Your own behalf and on Your sole responsibility, not on behalf\n      of any other Contributor, and only if You agree to indemnify,\n      defend, and hold each Contributor harmless for any liability\n      incurred by, or claims asserted against, such Contributor by reason\n      of your accepting any such warranty or additional liability.\n\n   END OF TERMS AND CONDITIONS\n\n   APPENDIX: How to apply the Apache License to your work.\n\n      To apply the Apache License to your work, attach the following\n      boilerplate notice, with the fields enclosed by brackets \"[]\"\n      replaced with your own identifying information. (Don't include\n      the brackets!)  The text should be enclosed in the appropriate\n      comment syntax for the file format. We also recommend that a\n      file or class name and description of purpose be included on the\n      same \"printed page\" as the copyright notice for easier\n      identification within third-party archives.\n\n   Copyright 2022 Software Mansion\n\n   Licensed under the Apache License, Version 2.0 (the \"License\");\n   you may not use this file except in compliance with the License.\n   You may obtain a copy of the License at\n\n       http://www.apache.org/licenses/LICENSE-2.0\n\n   Unless required by applicable law or agreed to in writing, software\n   distributed under the License is distributed on an \"AS IS\" BASIS,\n   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n   See the License for the specific language governing permissions and\n   limitations under the License.","ref":"license.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}